@@ -4,8 +4,8 @@ function (object, x = NULL, ..., b = 1000, type = "lmg", rank = TRUE, diff = TRU
     weights = NULL, design = NULL)
 {
      ynam = deparse(substitute(object))  ## make labelling of y ok
-     do.call("boot.relimp.default.intern", list(object=object, x=x, ...,b=b,
+     do.call("boot.relimp_default.intern", list(object=object, x=x, ...,b=b,
            type=type, diff=diff, rank=rank, rela=rela, always=always,
           groups=groups, groupnames = groupnames, fixed=fixed,
           weights=weights, design=design,ynam=ynam))
-}
\ No newline at end of file
+}
